==> syncope-2.0.11-source-release.zip: syncope-2.0.11/core/workflow-flowable/src/main/java/org/apache/syncope/core/workflow/flowable/task/AbstractFlowableServiceTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.workflow.flowable.task;

import org.activiti.engine.ProcessEngine;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * Abstract base class for Flowable's service tasks in Syncope, with Spring support.
 */
@Component
public abstract class AbstractFlowableServiceTask {

    protected static final Logger LOG = LoggerFactory.getLogger(AbstractFlowableServiceTask.class);

    @Autowired
    protected ProcessEngine engine;

    @Transactional(rollbackFor = { Throwable.class })
    public void execute(final String executionId) {
        doExecute(executionId);
    }

    protected abstract void doExecute(final String executionId);
}

==> syncope-2.0.14-source-release.zip: syncope-2.0.14/core/workflow-flowable/src/main/java/org/apache/syncope/core/workflow/flowable/task/AbstractFlowableServiceTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.workflow.flowable.task;

import org.activiti.engine.ProcessEngine;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * Abstract base class for Flowable's service tasks in Syncope, with Spring support.
 */
@Component
public abstract class AbstractFlowableServiceTask {

    protected static final Logger LOG = LoggerFactory.getLogger(AbstractFlowableServiceTask.class);

    @Autowired
    protected ProcessEngine engine;

    @Transactional(rollbackFor = { Throwable.class })
    public void execute(final String executionId) {
        doExecute(executionId);
    }

    protected abstract void doExecute(String executionId);
}
